﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Persist.Model;
using System.Collections;

namespace Persist.Services
{
    public class PersonServices
    {
        HotelSiteEntities Context;

        public PersonServices()
        {
            this.Context = new HotelSiteEntities();
        }

        public void Create(Person person)
        {
            Context.People.AddObject(person);
            Context.SaveChanges();
        }

        public void Update(Person person)
        {
            Person result = Find(person.PersonID);

            result.UserType_ID = person.UserType_ID;
            result.Address = person.Address;
            result.Family = person.Family;
            result.Name = person.Name;
            result.Password = person.Password;
            result.UserName = person.UserName;
            result.Telephone = person.Telephone;
            result.Email = person.Email;

            Context.SaveChanges();
        }

        public void Delete(int personID)
        {
            Person result = Find(personID);

            Context.People.DeleteObject(result);
            Context.SaveChanges();
        }

        public Person Find(int personID)
        {
            Person result = Context.People.Where(r => r.PersonID == personID).SingleOrDefault();
            return result;
        }

        public List<Person> FindAll()
        {
            List<Person> results = Context.People.Select(r => r).ToList();
            return results;
        }

        public Person GetUserID(string username)
        {
            Person result = Context.People.Where(r => r.UserName == username).SingleOrDefault();
            return result;
        }

        public List<Reserve> GetReserves(int person_ID)
        {
            List<Reserve> results = Context.Reserves.Where(r => r.Person_ID == person_ID).ToList();
            return results;
        }

        public ICollection SelectWithParent()
        {
            ICollection results = Context.People.Select(r => new
            {
                r.PersonID,
                r.Address,
                r.Family,
                r.Name,
                r.Password,
                r.UserName,
                r.Telephone,
                r.Email,
                UserType_Title = r.UserType.Title,
            }).ToList();
            return results;
        }

        public Person Login(string userName, string password)
        {
            Person person = Context.People.Where(r => r.UserName == userName && r.Password == password).SingleOrDefault();
            return person;
        }

        public ICollection GetPermissionToPage(string userName, string pageName)
        {
            var person = Context.People.Join(Context.UserTypes, p => p.UserType_ID, u => u.UserTypeID, (p, u) => new
            {
                p,
                u
            }).Join(Context.Accesses, r => r.u.UserTypeID, a => a.UserType_ID, (r, a) => new
            {
                r.p,
                r.u,
                a
            }).Join(Context.Pages, t => t.a.Page_ID, page => page.PageID, (t, page) => new
            {
                t.a,
                t.p,
                t.u,
                page
            }).Where(r => r.p.UserName == userName && r.page.PageName == pageName).ToList();


            return person;
        }

        public void RefreshContext()
        {
            Context = new HotelSiteEntities();
        }
    }
}