﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Persist.Model;
using System.Collections;

namespace Persist.Services
{
    public class RoomServices
    {
        HotelSiteEntities Context;

        public RoomServices()
        {
            this.Context = new HotelSiteEntities();
        }

        public void Create(Room room)
        {
            Context.Rooms.AddObject(room);
            Context.SaveChanges();
        }

        public void Update(Room room)
        {
            Room result = Find(room.RoomID);

            result.Description = room.Description;
            result.RoomNumber = room.RoomNumber;
            result.Price = room.Price;
            result.CountBedroom = room.CountBedroom;

            Context.SaveChanges();
        }

        public void Delete(int roomID)
        {
            Room result = Find(roomID);

            Context.Rooms.DeleteObject(result);
            Context.SaveChanges();
        }

        public Room Find(int roomID)
        {
            Room result = Context.Rooms.Where(r => r.RoomID == roomID).SingleOrDefault();
            return result;
        }

        public List<Room> FindAll()
        {
            List<Room> results = Context.Rooms.Select(r => r).ToList();
            return results;
        }

        public List<Reserve> GetReserves(int room_ID)
        {
            List<Reserve> results = Context.Reserves.Where(r => r.Room_ID == room_ID).ToList();
            return results;
        }

        //گزارش 1
        //لیستی از اتاق ها به همراه اطلاعات کامل
        public ICollection ReportOfRoomsWithInformationComplete()
        {
            ICollection result = FindAll();
            return result;
        }

        //گزارش 2
        //لیست اتاق پر در تاریخ فلان 
        public ICollection ReportOfFullRoom(DateTime date, int roomID)
        {
            ICollection result = Context.Reserves.Where(r => r.StartDate.Year * 365 + r.StartDate.Month * 31 + r.StartDate.Day <= date.Year * 365 + date.Month * 31 + date.Day &&
                                                             r.EndDate.Year * 365 + r.EndDate.Month * 31 + r.EndDate.Day >= date.Year * 365 + date.Month * 31 + date.Day
                                                             && r.Room_ID == roomID).ToList();

            return result;
        }

        //گزارش 3
        //لیست اتاق های ایکس خوابه
        public List<Room> ReportOfXBedroomRoom(int x)
        {
            List<Room> rooms = Context.Rooms.Where(r => r.CountBedroom == x).ToList();

            return rooms;
        }

        //گزارش 4
        //لیست اتاق هایی با رنج قیمت خاص
        public List<Room> ReportOfPriceRoom(double xPrice, double yPrice)
        {
            List<Room> rooms = Context.Rooms.Where(r => r.Price >= xPrice && r.Price <= yPrice).ToList();
            return rooms;
        }

        //گزارش 5
        //لیست اتاق های ایکس خوابه با رنج قیمت خاص
        public List<Room> ReportOfPriceAndXBedroom(double xPrice, double yPrice, int x)
        {
            List<Room> rooms = Context.Rooms.Where(r => r.Price >= xPrice && r.Price <= yPrice && r.CountBedroom == x).ToList();
            return rooms;
        }

        //گزارش 6
        //لیست اتاق ایکس خوابه پر در تاریخ فلان 
        public ICollection ReportOfFullXBedroom(DateTime date, int roomID, int x)
        {
            ICollection result = Context.Reserves.Where(r => r.StartDate.Year * 365 + r.StartDate.Month * 31 + r.StartDate.Day <= date.Year * 365 + date.Month * 31 + date.Day &&
                                                             r.EndDate.Year * 365 + r.EndDate.Month * 31 + r.EndDate.Day >= date.Year * 365 + date.Month * 31 + date.Day
                                                             && r.Room_ID == roomID
                                                             && r.Room.CountBedroom == x).ToList();

            return result;
        }

        //گزارش 7
        //لیست اتاق ایکس خوابه در رنج قیمت خاص پر در تاریخ فلان 
        public ICollection ReportOfFullXBedroomAndRangePrice(DateTime date, int roomID, int x, double xPrice, double yPrice)
        {
            ICollection result = Context.Reserves.Where(r => r.StartDate.Year * 365 + r.StartDate.Month * 31 + r.StartDate.Day <= date.Year * 365 + date.Month * 31 + date.Day &&
                                                             r.EndDate.Year * 365 + r.EndDate.Month * 31 + r.EndDate.Day >= date.Year * 365 + date.Month * 31 + date.Day
                                                             && r.Room_ID == roomID
                                                             && r.Room.CountBedroom == x
                                                             && r.Room.Price >= xPrice && r.Room.Price <= yPrice).ToList();

            return result;
        }

        public void RefreshContext()
        {
            Context = new HotelSiteEntities();
        }
    }
}