﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.IO;
namespace Presentation.Pages.Admin
{
    public partial class ManageAccess : System.Web.UI.Page
    {
        Business.Controller.AccessController AccessController;
        Business.Controller.UserTypeController UserTypeController;
        Business.Controller.PageController PageController;
        Business.Classes.DateTimeBusiness DateTimeBusiness;
        Business.Controller.PersonController PersonController;

        public ManageAccess()
        {
            this.AccessController = new Business.Controller.AccessController();
            this.UserTypeController = new Business.Controller.UserTypeController();
            this.PageController = new Business.Controller.PageController();
            this.DateTimeBusiness = new Business.Classes.DateTimeBusiness();
            PersonController = new Business.Controller.PersonController();
        }

        protected override void OnInit(EventArgs e)
        {
            ddlUserType.DataSource = UserTypeController.FindAll();
            ddlUserType.DataBind(); ddlPage.DataSource = PageController.FindAll();
            ddlPage.DataBind();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!PersonController.IsPermissionToPage(HttpContext.Current.User.Identity.Name, this.Title))
                Response.Redirect("~/Pages/Forbidden.aspx");

            BindGridView();
        }

        protected void grdAccess_RowDeleting(object sender, GridViewDeleteEventArgs e)
        {
            BindGridView();
        }

        protected void grdAccess_RowEditing(object sender, GridViewEditEventArgs e)
        {
            BindGridView();
        }

        protected void grdAccess_RowUpdating(object sender, GridViewUpdateEventArgs e)
        {
            BindGridView();
        }

        protected void grdAccess_RowCommand(object sender, GridViewCommandEventArgs e)
        {
            ViewState["AccessID"] = e.CommandArgument.ToString();
            int accessID = Convert.ToInt32(e.CommandArgument.ToString());
            switch (e.CommandName.ToString())
            {
                case "doEdit":
                    {
                        ResetAccess();
                        ViewState["Mode"] = "doEdit";
                        LoadAccess(accessID);
                        mvAccess.SetActiveView(vwInsertUpdateAccess);
                        break;
                    }
                case "doDelete":
                    {
                        this.AccessController.Delete(accessID);
                        BindGridView();
                        break;
                    }
            }
        }

        protected void grdAccess_PageIndexChanging(object sender, GridViewPageEventArgs e)
        {
            grdAccess.PageIndex = e.NewPageIndex;
            BindGridView();
        }

        private void BindGridView()
        {
            this.grdAccess.DataSource = AccessController.SelectWithParent();
            this.grdAccess.DataBind();
        }

        private void ResetAccess()
        {
        }

        private void LoadAccess(int accessID)
        {
            Persist.Model.Access access = this.AccessController.Find(accessID);
            if (access != null)
            {
                ddlUserType.SelectedValue = access.UserType_ID.ToString();
                ddlPage.SelectedValue = access.Page_ID.ToString();
            }
        }

        private bool CreateAccess()
        {
            bool status = AccessController.Create(new Persist.Model.Access()
            {
                UserType_ID = Convert.ToInt32(ddlUserType.SelectedValue),
                Page_ID = Convert.ToInt32(ddlPage.SelectedValue)
            });
            return status;
        }

        private bool UpdateAccess(int accessID)
        {
            bool status = AccessController.Update(new Persist.Model.Access()
            {
                AccessID = accessID,
                UserType_ID = Convert.ToInt32(ddlUserType.SelectedValue),
                Page_ID = Convert.ToInt32(ddlPage.SelectedValue)
            });
            return status;
        }

        protected void btnCancelAccess_Click(object sender, EventArgs e)
        {
            mvAccess.SetActiveView(vwManagementAccess);
        }

        protected void btnInsertAccess_Click(object sender, EventArgs e)
        {
            ViewState["Mode"] = "Insert";
            ResetAccess();
            mvAccess.SetActiveView(vwInsertUpdateAccess);
        }

        protected void btnInsertAndUpdateAccess_Click(object sender, EventArgs e)
        {
            bool status;
            if (ViewState["Mode"].ToString().ToLower() == "insert")
            {
                status = CreateAccess();
            }
            else
            {
                status = UpdateAccess(Convert.ToInt32(ViewState["AccessID"].ToString()));
            }
            if (status)
            {
                BindGridView();
                mvAccess.SetActiveView(vwManagementAccess);
            }
        }

        protected void btnReturnToPanelAccess_Click(object sender, EventArgs e)
        {
            Response.Redirect("~/Pages/Admin/Default.aspx");
        }
    }
}