﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.IO;
namespace Presentation.Pages.Admin
{
    public partial class ManagePage : System.Web.UI.Page
    {
        Business.Controller.PageController PageController;
        Business.Classes.DateTimeBusiness DateTimeBusiness;
        Business.Controller.PersonController PersonController;

        public ManagePage()
        {
            this.PageController = new Business.Controller.PageController();
            this.DateTimeBusiness = new Business.Classes.DateTimeBusiness();
            PersonController = new Business.Controller.PersonController();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!PersonController.IsPermissionToPage(HttpContext.Current.User.Identity.Name, this.Title))
                Response.Redirect("~/Pages/Forbidden.aspx");

            BindGridView();
        }

        protected void grdPage_RowDeleting(object sender, GridViewDeleteEventArgs e)
        {
            BindGridView();
        }

        protected void grdPage_RowEditing(object sender, GridViewEditEventArgs e)
        {
            BindGridView();
        }

        protected void grdPage_RowUpdating(object sender, GridViewUpdateEventArgs e)
        {
            BindGridView();
        }

        protected void grdPage_RowCommand(object sender, GridViewCommandEventArgs e)
        {
            ViewState["PageID"] = e.CommandArgument.ToString();
            int pageID = Convert.ToInt32(e.CommandArgument.ToString());
            switch (e.CommandName.ToString())
            {
                case "doEdit":
                    {
                        ResetPage();
                        ViewState["Mode"] = "doEdit";
                        LoadPage(pageID);
                        mvPage.SetActiveView(vwInsertUpdatePage);
                        break;
                    }
                case "doDelete":
                    {
                        this.PageController.Delete(pageID);
                        BindGridView();
                        break;
                    }
            }
        }

        protected void grdPage_PageIndexChanging(object sender, GridViewPageEventArgs e)
        {
            grdPage.PageIndex = e.NewPageIndex;
            BindGridView();
        }

        private void BindGridView()
        {
            this.grdPage.DataSource = PageController.FindAll();
            this.grdPage.DataBind();
        }

        private void ResetPage()
        {
            txtPageName.Text = string.Empty;
        }

        private void LoadPage(int pageID)
        {
            Persist.Model.Page page = this.PageController.Find(pageID);
            if (page != null)
            {
                txtPageName.Text = page.PageName.ToString();
            }
        }

        private bool CreatePage()
        {
            bool status = PageController.Create(new Persist.Model.Page()
            {
                PageName = Convert.ToString(txtPageName.Text)
            });
            return status;
        }

        private bool UpdatePage(int pageID)
        {
            bool status = PageController.Update(new Persist.Model.Page()
            {
                PageID = pageID,
                PageName = Convert.ToString(txtPageName.Text)
            });
            return status;
        }

        protected void btnCancelPage_Click(object sender, EventArgs e)
        {
            mvPage.SetActiveView(vwManagementPage);
        }

        protected void btnInsertPage_Click(object sender, EventArgs e)
        {
            ViewState["Mode"] = "Insert";
            ResetPage();
            mvPage.SetActiveView(vwInsertUpdatePage);
        }

        protected void btnInsertAndUpdatePage_Click(object sender, EventArgs e)
        {
            bool status;
            if (ViewState["Mode"].ToString().ToLower() == "insert")
            {
                status = CreatePage();
            }
            else
            {
                status = UpdatePage(Convert.ToInt32(ViewState["PageID"].ToString()));
            }
            if (status)
            {
                BindGridView();
                mvPage.SetActiveView(vwManagementPage);
            }
        }

        protected void btnReturnToPanelPage_Click(object sender, EventArgs e)
        {
            Response.Redirect("~/Pages/Admin/Default.aspx");
        }
    }
}