﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.IO;
namespace Presentation.Pages.Admin
{
    public partial class ManagePerson : System.Web.UI.Page
    {
        Business.Controller.PersonController PersonController;
        Business.Controller.UserTypeController UserTypeController;
        Business.Classes.DateTimeBusiness DateTimeBusiness;

        public ManagePerson()
        {
            this.PersonController = new Business.Controller.PersonController();
            this.UserTypeController = new Business.Controller.UserTypeController();
            this.DateTimeBusiness = new Business.Classes.DateTimeBusiness();
        }

        protected override void OnInit(EventArgs e)
        {
            ddlUserType.DataSource = UserTypeController.FindAll();
            ddlUserType.DataBind();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!PersonController.IsPermissionToPage(HttpContext.Current.User.Identity.Name, this.Title))
                Response.Redirect("~/Pages/Forbidden.aspx");

            BindGridView();
        }

        protected void grdPerson_RowDeleting(object sender, GridViewDeleteEventArgs e)
        {
            BindGridView();
        }

        protected void grdPerson_RowEditing(object sender, GridViewEditEventArgs e)
        {
            BindGridView();
        }

        protected void grdPerson_RowUpdating(object sender, GridViewUpdateEventArgs e)
        {
            BindGridView();
        }

        protected void grdPerson_RowCommand(object sender, GridViewCommandEventArgs e)
        {
            ViewState["PersonID"] = e.CommandArgument.ToString();
            int personID = Convert.ToInt32(e.CommandArgument.ToString());
            switch (e.CommandName.ToString())
            {
                case "doEdit":
                    {
                        ResetPerson();
                        ViewState["Mode"] = "doEdit";
                        LoadPerson(personID);
                        mvPerson.SetActiveView(vwInsertUpdatePerson);
                        break;
                    }
                case "doDelete":
                    {
                        this.PersonController.Delete(personID);
                        BindGridView();
                        break;
                    }
            }
        }

        protected void grdPerson_PageIndexChanging(object sender, GridViewPageEventArgs e)
        {
            grdPerson.PageIndex = e.NewPageIndex;
            BindGridView();
        }

        private void BindGridView()
        {
            this.grdPerson.DataSource = PersonController.SelectWithParent();
            this.grdPerson.DataBind();
        }

        private void ResetPerson()
        {
            txtAddress.Text = string.Empty;
            txtFamily.Text = string.Empty;
            txtName.Text = string.Empty;
            txtPassword.Text = string.Empty;
            txtUserName.Text = string.Empty;
            txtNationalCode.Text = string.Empty;
            txtTelephone.Text = string.Empty;
            txtEmail.Text = string.Empty;
            rbSexYes.Checked = true;
        }

        private void LoadPerson(int personID)
        {
            Persist.Model.Person person = this.PersonController.Find(personID);
            if (person != null)
            {
                txtAddress.Text = person.Address.ToString();
                txtFamily.Text = person.Family.ToString();
                txtName.Text = person.Name.ToString();
                txtPassword.Text = person.Password.ToString();
                txtUserName.Text = person.UserName.ToString();
                txtTelephone.Text = person.Telephone.ToString();
                txtEmail.Text = person.Email.ToString();

                ddlUserType.SelectedValue = person.UserType_ID.ToString();
            }
        }

        private bool CreatePerson()
        {
            bool status = PersonController.Create(new Persist.Model.Person()
            {
                Address = Convert.ToString(txtAddress.Text),
                Family = Convert.ToString(txtFamily.Text),
                Name = Convert.ToString(txtName.Text),
                Password = Convert.ToString(txtPassword.Text),
                UserName = Convert.ToString(txtUserName.Text),
                Telephone = Convert.ToString(txtTelephone.Text),
                Email = Convert.ToString(txtEmail.Text),
                UserType_ID = Convert.ToInt32(ddlUserType.SelectedValue)
            });
            return status;
        }

        private bool UpdatePerson(int personID)
        {
            bool status = PersonController.Update(new Persist.Model.Person()
            {
                PersonID = personID,
                Address = Convert.ToString(txtAddress.Text),
                Family = Convert.ToString(txtFamily.Text),
                Name = Convert.ToString(txtName.Text),
                Password = Convert.ToString(txtPassword.Text),
                UserName = Convert.ToString(txtUserName.Text),
                Telephone = Convert.ToString(txtTelephone.Text),
                Email = Convert.ToString(txtEmail.Text),
                UserType_ID = Convert.ToInt32(ddlUserType.SelectedValue)
            });
            return status;
        }

        protected void btnCancelPerson_Click(object sender, EventArgs e)
        {
            mvPerson.SetActiveView(vwManagementPerson);
        }

        protected void btnInsertPerson_Click(object sender, EventArgs e)
        {
            ViewState["Mode"] = "Insert";
            ResetPerson();
            mvPerson.SetActiveView(vwInsertUpdatePerson);
        }

        protected void btnInsertAndUpdatePerson_Click(object sender, EventArgs e)
        {
            bool status;
            if (ViewState["Mode"].ToString().ToLower() == "insert")
            {
                status = CreatePerson();
            }
            else
            {
                status = UpdatePerson(Convert.ToInt32(ViewState["PersonID"].ToString()));
            }
            if (status)
            {
                BindGridView();
                mvPerson.SetActiveView(vwManagementPerson);
            }
        }

        protected void btnReturnToPanelPerson_Click(object sender, EventArgs e)
        {
            Response.Redirect("~/Pages/Admin/Default.aspx");
        }
    }
}