﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.IO;
namespace Presentation.Pages.Admin
{
    public partial class ManageReserve : System.Web.UI.Page
    {
        Business.Controller.ReserveController ReserveController;
        Business.Controller.PersonController PersonController;
        Business.Controller.RoomController RoomController;
        Business.Classes.DateTimeBusiness DateTimeBusiness;

        public ManageReserve()
        {
            this.ReserveController = new Business.Controller.ReserveController();
            this.PersonController = new Business.Controller.PersonController();
            this.RoomController = new Business.Controller.RoomController();
            this.DateTimeBusiness = new Business.Classes.DateTimeBusiness();
        }

        protected override void OnInit(EventArgs e)
        {
            ddlPerson.DataSource = PersonController.FindAll();
            ddlPerson.DataBind(); ddlRoom.DataSource = RoomController.FindAll();
            ddlRoom.DataBind();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!PersonController.IsPermissionToPage(HttpContext.Current.User.Identity.Name, this.Title))
                Response.Redirect("~/Pages/Forbidden.aspx");

            BindGridView();
        }

        protected void grdReserve_RowDeleting(object sender, GridViewDeleteEventArgs e)
        {
            BindGridView();
        }

        protected void grdReserve_RowEditing(object sender, GridViewEditEventArgs e)
        {
            BindGridView();
        }

        protected void grdReserve_RowUpdating(object sender, GridViewUpdateEventArgs e)
        {
            BindGridView();
        }

        protected void grdReserve_RowCommand(object sender, GridViewCommandEventArgs e)
        {
            ViewState["ReserveID"] = e.CommandArgument.ToString();
            int reserveID = Convert.ToInt32(e.CommandArgument.ToString());
            switch (e.CommandName.ToString())
            {
                case "doEdit":
                    {
                        ResetReserve();
                        ViewState["Mode"] = "doEdit";
                        LoadReserve(reserveID);
                        mvReserve.SetActiveView(vwInsertUpdateReserve);
                        break;
                    }
                case "doDelete":
                    {
                        this.ReserveController.Delete(reserveID);
                        BindGridView();
                        break;
                    }
            }
        }

        protected void grdReserve_PageIndexChanging(object sender, GridViewPageEventArgs e)
        {
            grdReserve.PageIndex = e.NewPageIndex;
            BindGridView();
        }

        private void BindGridView()
        {
            this.grdReserve.DataSource = ReserveController.SelectWithParent();
            this.grdReserve.DataBind();
        }

        private void ResetReserve()
        {
            txtPriceSum.Text = string.Empty;
            pdtEndDate.Text = string.Empty;
            pdtStartDate.Text = string.Empty;
        }

        private void LoadReserve(int reserveID)
        {
            Persist.Model.Reserve reserve = this.ReserveController.Find(reserveID);
            if (reserve != null)
            {
                txtPriceSum.Text = reserve.PriceSum.ToString();
                pdtEndDate.Text = DateTimeBusiness.ConvertToShamsi(reserve.EndDate.ToString());
                pdtStartDate.Text = DateTimeBusiness.ConvertToShamsi(reserve.StartDate.ToString());
                ddlPerson.SelectedValue = reserve.Person_ID.ToString();
                ddlRoom.SelectedValue = reserve.Room_ID.ToString();
            }
        }

        private bool CreateReserve()
        {
            bool status = ReserveController.Create(new Persist.Model.Reserve()
            {
                PriceSum = Convert.ToDouble(txtPriceSum.Text),
                EndDate = DateTimeBusiness.ConvertToMilady(pdtEndDate.Text),
                StartDate = DateTimeBusiness.ConvertToMilady(pdtStartDate.Text),
                Person_ID = Convert.ToInt32(ddlPerson.SelectedValue),
                Room_ID = Convert.ToInt32(ddlRoom.SelectedValue)
            });
            return status;
        }

        private bool UpdateReserve(int reserveID)
        {
            bool status = ReserveController.Update(new Persist.Model.Reserve()
            {
                ReserveID = reserveID,
                PriceSum = Convert.ToDouble(txtPriceSum.Text),
                EndDate = DateTimeBusiness.ConvertToMilady(pdtEndDate.Text),
                StartDate = DateTimeBusiness.ConvertToMilady(pdtStartDate.Text),
                Person_ID = Convert.ToInt32(ddlPerson.SelectedValue),
                Room_ID = Convert.ToInt32(ddlRoom.SelectedValue)
            });
            return status;
        }

        protected void btnCancelReserve_Click(object sender, EventArgs e)
        {
            mvReserve.SetActiveView(vwManagementReserve);
        }

        protected void btnInsertReserve_Click(object sender, EventArgs e)
        {
            ViewState["Mode"] = "Insert";
            ResetReserve();
            mvReserve.SetActiveView(vwInsertUpdateReserve);
        }

        protected void btnInsertAndUpdateReserve_Click(object sender, EventArgs e)
        {
            bool status;
            if (ViewState["Mode"].ToString().ToLower() == "insert")
            {
                status = CreateReserve();
            }
            else
            {
                status = UpdateReserve(Convert.ToInt32(ViewState["ReserveID"].ToString()));
            }
            if (status)
            {
                BindGridView();
                mvReserve.SetActiveView(vwManagementReserve);
            }
        }

        protected void btnReturnToPanelReserve_Click(object sender, EventArgs e)
        {
            Response.Redirect("~/Pages/Admin/Default.aspx");
        }
    }
}