﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.IO;
namespace Presentation.Pages.Admin
{
    public partial class ManageUserType : System.Web.UI.Page
    {
        Business.Controller.UserTypeController UserTypeController;
        Business.Classes.DateTimeBusiness DateTimeBusiness;
        Business.Controller.PersonController PersonController;

        public ManageUserType()
        {
            this.UserTypeController = new Business.Controller.UserTypeController();
            this.DateTimeBusiness = new Business.Classes.DateTimeBusiness();
            PersonController = new Business.Controller.PersonController();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!PersonController.IsPermissionToPage(HttpContext.Current.User.Identity.Name, this.Title))
                Response.Redirect("~/Pages/Forbidden.aspx");

            BindGridView();
        }

        protected void grdUserType_RowDeleting(object sender, GridViewDeleteEventArgs e)
        {
            BindGridView();
        }

        protected void grdUserType_RowEditing(object sender, GridViewEditEventArgs e)
        {
            BindGridView();
        }

        protected void grdUserType_RowUpdating(object sender, GridViewUpdateEventArgs e)
        {
            BindGridView();
        }

        protected void grdUserType_RowCommand(object sender, GridViewCommandEventArgs e)
        {
            ViewState["UserTypeID"] = e.CommandArgument.ToString();
            int userTypeID = Convert.ToInt32(e.CommandArgument.ToString());
            switch (e.CommandName.ToString())
            {
                case "doEdit":
                    {
                        ResetUserType();
                        ViewState["Mode"] = "doEdit";
                        LoadUserType(userTypeID);
                        mvUserType.SetActiveView(vwInsertUpdateUserType);
                        break;
                    }
                case "doDelete":
                    {
                        this.UserTypeController.Delete(userTypeID);
                        BindGridView();
                        break;
                    }
            }
        }

        protected void grdUserType_PageIndexChanging(object sender, GridViewPageEventArgs e)
        {
            grdUserType.PageIndex = e.NewPageIndex;
            BindGridView();
        }

        private void BindGridView()
        {
            this.grdUserType.DataSource = UserTypeController.FindAll();
            this.grdUserType.DataBind();
        }

        private void ResetUserType()
        {
            txtTitle.Text = string.Empty;
        }

        private void LoadUserType(int userTypeID)
        {
            Persist.Model.UserType userType = this.UserTypeController.Find(userTypeID);
            if (userType != null)
            {
                txtTitle.Text = userType.Title.ToString();
            }
        }

        private bool CreateUserType()
        {
            bool status = UserTypeController.Create(new Persist.Model.UserType()
            {
                Title = Convert.ToString(txtTitle.Text)
            });
            return status;
        }

        private bool UpdateUserType(int userTypeID)
        {
            bool status = UserTypeController.Update(new Persist.Model.UserType()
            {
                UserTypeID = userTypeID,
                Title = Convert.ToString(txtTitle.Text)
            });
            return status;
        }

        protected void btnCancelUserType_Click(object sender, EventArgs e)
        {
            mvUserType.SetActiveView(vwManagementUserType);
        }

        protected void btnInsertUserType_Click(object sender, EventArgs e)
        {
            ViewState["Mode"] = "Insert";
            ResetUserType();
            mvUserType.SetActiveView(vwInsertUpdateUserType);
        }

        protected void btnInsertAndUpdateUserType_Click(object sender, EventArgs e)
        {
            bool status;
            if (ViewState["Mode"].ToString().ToLower() == "insert")
            {
                status = CreateUserType();
            }
            else
            {
                status = UpdateUserType(Convert.ToInt32(ViewState["UserTypeID"].ToString()));
            }
            if (status)
            {
                BindGridView();
                mvUserType.SetActiveView(vwManagementUserType);
            }
        }

        protected void btnReturnToPanelUserType_Click(object sender, EventArgs e)
        {
            Response.Redirect("~/Pages/Admin/Default.aspx");
        }
    }
}