﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace Presentation.Pages.Member
{
    public partial class ReserveRoom : System.Web.UI.Page
    {
        Business.Controller.ReserveController ReserveController;
        Business.Controller.PersonController PersonController;
        Business.Controller.RoomController RoomController;
        Business.Classes.DateTimeBusiness DateTimeBusiness;

        public ReserveRoom()
        {
            this.ReserveController = new Business.Controller.ReserveController();
            this.PersonController = new Business.Controller.PersonController();
            this.RoomController = new Business.Controller.RoomController();
            this.DateTimeBusiness = new Business.Classes.DateTimeBusiness();
        }

        protected override void OnInit(EventArgs e)
        {
            ddlRoom.DataSource = RoomController.FindAll();
            ddlRoom.DataBind();

            if (ddlRoom.Items.Count > 0)
            {
                SetRoomInformation(int.Parse(ddlRoom.SelectedValue.ToString()));
            }

        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!PersonController.IsPermissionToPage(HttpContext.Current.User.Identity.Name, this.Title))
                Response.Redirect("~/Pages/Forbidden.aspx");
        }

        private void SetRoomInformation(int roomID)
        {
            Persist.Model.Room room = RoomController.Find(roomID);

            lblRoomInformation.Text = "شماره اتاق : " + room.RoomNumber + "<br />";
            lblRoomInformation.Text += "تعداد تخت : " + room.CountBedroom + "<br />";
            lblRoomInformation.Text += "اجاره : " + room.Price + " ریال" + "<br />";
            lblRoomInformation.Text += "توضیحات : " + room.Description + "<br /> <br />";
        }

        protected void btnInsertAndUpdateReserve_Click(object sender, EventArgs e)
        {
            if (Page.IsValid)
            {
                string username = HttpContext.Current.User.Identity.Name;
                int userID = PersonController.GetUserID(username);

                bool status = ReserveController.Create(new Persist.Model.Reserve()
                {
                    EndDate = DateTimeBusiness.ConvertToMilady(pdtEndDate.Text),
                    StartDate = DateTimeBusiness.ConvertToMilady(pdtStartDate.Text),
                    Person_ID = userID,
                    Room_ID = Convert.ToInt32(ddlRoom.SelectedValue)
                });

                if (status)
                {
                    lblResult.Text = "اتاق برای شما رزرو گردید";
                }
                else
                {
                    lblResult.Text = "اتاق رزرو نشد";
                }
            }
        }

        protected void btnCancelReserve_Click(object sender, EventArgs e)
        {

        }

        protected void ddlRoom_SelectedIndexChanged(object sender, EventArgs e)
        {
            SetRoomInformation(int.Parse(ddlRoom.SelectedValue.ToString()));
        }

        protected void cvStartDate_ServerValidate(object source, ServerValidateEventArgs args)
        {
            DateTime dateSelected = DateTimeBusiness.ConvertToMilady(pdtStartDate.Text);
            DateTime dateNow = DateTime.Now;

            args.IsValid = (dateSelected.Year * 365 + dateSelected.Month * 31 + dateSelected.Day >=
                            dateNow.Year * 365 + dateNow.Month * 31 + dateNow.Day) ? true : false;
        }
    }
}